@@ -1,9 +1,9 @@
-from easydata.queries.jp import JmesPathSearch
+from easydata.queries.jp import JMESPathSearch
 from easydata.queries.key import KeyQuery
 from easydata.queries.pq import PyQuerySearch
 from easydata.queries.re import ReQuery
 
-jp = JmesPathSearch
+jp = JMESPathSearch
 key = KeyQuery
 pq = PyQuerySearch
 re = ReQuery
