@@ -65,10 +65,10 @@ def test_list_config():
 
 def test_list_config_override():
     # Lets test if config settings can get overriden
-    list_parser = parsers.List(parser=parsers.Url(domain="http://demo.net"))
+    list_parser = parsers.List(parser=parsers.Url(domain="https://demo.net"))
     list_parser.init_config({"ED_URL_DOMAIN": "demo.com"})
 
-    assert list_parser.parse(["/imgs/1.jpg"]) == ["http://demo.net/imgs/1.jpg"]
+    assert list_parser.parse(["/imgs/1.jpg"]) == ["https://demo.net/imgs/1.jpg"]
 
 
 def test_list_unique_true():
@@ -96,12 +96,19 @@ def test_list_unique_false():
     assert list_parser.parse(data_html.images) == expected_urls_non_unique
 
 
-def test_list_max_num():
-    list_parser = parsers.List(
-        pq("#image-container img::items"), parsers.Url(pq("::src")), max_num=2
-    )
+@pytest.mark.parametrize(
+    "max_num, result",
+    [
+        (2, ["one", "two"]),
+        (4, ["one", "two", "three", "four"]),
+        (5, ["one", "two", "three", "four"]),
+        (-1, ["one", "two", "three"]),
+    ],
+)
+def test_list_max_num(max_num, result):
+    list_parser = parsers.List(max_num=max_num)
 
-    assert list_parser.parse(data_html.images) == expected_urls_max_2
+    assert list_parser.parse(["one", "two", "three", "four"]) == result
 
 
 def test_list_split_key():
@@ -284,10 +291,10 @@ def test_url_list_config():
 
 def test_url_list_config_override():
     # Lets test if config settings can get overriden
-    url_list_parser = parsers.UrlList(domain="http://demo.net")
+    url_list_parser = parsers.UrlList(domain="https://demo.net")
     url_list_parser.init_config({"ED_URL_DOMAIN": "demo.com"})
 
-    assert url_list_parser.parse(["/imgs/1.jpg"]) == ["http://demo.net/imgs/1.jpg"]
+    assert url_list_parser.parse(["/imgs/1.jpg"]) == ["https://demo.net/imgs/1.jpg"]
 
 
 @pytest.mark.parametrize(
